#!/bin/sh
#
# by Chih-Wei Huang
# modified by Pablo Saratxaga <pablo@mandrakesoft.com>
# modified by Geoffrey Lee <snailtalk@mandrakesoft.com>
# modified by Andrew Lee <andrew@linux.org.tw>
#
#              Updated   22-24 July - 24 August 1999
#			 23 January 2001
#        Last modified   14 September 2001
#

#PATH="/bin:/usr/bin:/usr/X11R6/bin:/usr/local/bin"
SCRIPTNAME=`basename $0`

RXVT=/usr/X11R6/bin/rxvt.cjk

if [ "$SCRIPTNAME" = "rxvt" -o "$SCRIPTNAME" = "rxvt.sh" -o "$SCRIPTNAME" = "xvt" ]; then
    if [ ! -z $LANGUAGE ]; then
        locale=`echo $LANGUAGE | cut -d: -f1`
    elif [ ! -z $LC_ALL ]; then
        locale=$LC_ALL
    elif [ ! -z $LC_CTYPE ]; then
        locale=$LC_CTYPE
    elif [ ! -z $LANG ]; then
        locale=$LANG
    fi

    case $locale in
        zh_TW*|zh_HK*)
        SCRIPTNAME=crxvt
        ;;

        zh_CN*)
        SCRIPTNAME=gbrxvt
	;;

	ja*)
	SCRIPTNAME=jrxvt
	;;

	ko*)
	SCRIPTNAME=krxvt
	;;

      # unknown locale, ignore it
    *)
	MENU=""
        ;;
    esac

    unset locale
fi

case $SCRIPTNAME in
    crxvt)
    LANG=zh_TW.Big5
    LANGUAGE="zh_TW.Big5:zh_TW:zh"
    ENC=big5
    XA_FACE=ming
    XA_FAMILY=default
    XIM=xcin
  #  MENU="/etc/rxvt/rxvt-zh.menu;big5"
    FNFONT="8x16"
    FMFONT="-default-ming-medium-r-normal--16-*-*-*-c-160-big5-0"
    _TITLE="Chinese"
    ;;

    gbrxvt)
    LANG=zh_CN.GB2312
    LANGUAGE=zh_CN.GB2312:zh_CN:zh
    ENC=gb
    XA_FACE=ming
    XA_FAMILY=default
    XIM=xcin-zh_CN.GB2312
    FNFONT="8x16"
   # MENU="/etc/rxvt/rxvt-zh.menu;gb"
    FMFONT="-default-ming-medium-r-normal--16-*-*-*-c-160-gb2312.1980-0"
    _TITLE="Chinese"
    ;;

    jrxvt)
    LANG=ja_JP
    LANGUAGE="ja_JP.EUC-JP:ja_JP.ujis:ja_JP:ja"
    FNFONT="8x16"
    ENC=eucj
    XIM=kinput2
    #MENU="/usr/share/rxvt/rxvt-ja;eucj"
    _TITLE="Japanese"
    ;;

    krxvt)
    LANG=ko_KR
    LANGUAGE="ko_KR.EUC-KR:ko_KR:ko"
    ENC=kr
    FNFONT="8x16"
    XIM=Ami
    #MENU="/usr/share/rxvt/rxvt-ko;kr"
    _TITLE="Korean"
    ;;

    # Locale other than jp / zh / ko, give ENC == noenc
    rxvt | xvt)
    RXVT="/usr/X11R6/bin/rxvt.bin"
    unset $ENC
    unset $XIM
    if [ -e $HOME/.Xresources ] && grep -iq 'rxvt.*\<font\>' $HOME/.Xresources; then
	:
    elif [ -e $HOME/.Xdefaults ] && grep -iq 'rxvt.*\<font\>' $HOME/.Xdefaults; then
	:
    else
	FNFONT="-*-fixed-medium-r-normal-*-*-140-75-75-*-*-iso8859-15"
    fi
    ;;
	
esac


export LANG LANGUAGE

FGCOLOR=lightgray
BGCOLOR=black
TITLE="$_TITLE RXVT ($LANG)"

ARGS=""

while [ -n "$1" ]; do
    case $1 in
        -km) shift
        ENC=$1
        ;;

        -im) shift
        XIM=$1
        ;;

        -fg) shift
        FGCOLOR=$1
        ;;

        -bg) shift
        BGCOLOR=$1
        ;;

        -T|-title) shift
        TITLE=$1
        ;;

        -menu) shift
        MENU="$1"
        ;;

        -nomenu)
        MENU=""
        ;;

        -fn) shift
        FNFONT="$1"
        ;;

        -fm) shift
        FMFONT="$1"
        ;;

        *)
        ARGS="$ARGS $1"
        ;;
    esac
    shift
done

[ -n "$BGCOLOR" ] && ARGS="-bg $BGCOLOR $ARGS"
[ -n "$FGCOLOR" ] && ARGS="-fg $FGCOLOR $ARGS"
[ -n "$ENC" ] && ARGS="-km $ENC $ARGS"
if [ -n "$XIM" -a -n "$ENC" ]; then
    ARGS="-im $XIM -mcc $ARGS" 
    export XMODIFIERS="@im=$XIM"
fi

# Alas! Dirty hack for font name containing spaces
# Is there any simpler solution??
if [ -n "$FNFONT" -a -n "$FMFONT" ]; then
    exec $RXVT -T "$TITLE" -menu "$MENU" -fn "$FNFONT" -fm "$FMFONT" $ARGS
elif [ -n "$FNFONT" ]; then
    exec $RXVT -T "$TITLE" -menu "$MENU" -fn "$FNFONT" $ARGS
elif [ -n "$FMFONT" ]; then
    exec $RXVT -T "$TITLE" -menu "$MENU" -fm "$FMFONT" $ARGS
else
    exec $RXVT -T "$TITLE" -menu "$MENU" $ARGS
fi

